.. :changelog:

History
-------

0.1.1 (2016-08-08)
++++++++++++++++++

* Rather use `django-storages` than the deprecated fork from `django-storages-redux`.


0.1.0 (2016-05-19)
++++++++++++++++++

* First release on PyPI.
